<?php

/**
 * The admin-facing functionality of the plugin.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package eventful-pro
 * @subpackage eventful-pro/Admin
 * @author     ThemeAtelier<themeatelierbd@gmail.com>
 */

namespace ThemeAtelier\EventfulPro\Admin;

use ThemeAtelier\EventfulPro\Admin\DBUpdates;
use ThemeAtelier\EventfulPro\Admin\Views\EventfulMetaboxes;
use ThemeAtelier\EventfulPro\Admin\Views\EventfulSettings;

class Admin
{
    protected $suffix;
    private $plugin_name;
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version)
    {
        $this->suffix      = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG || defined('WP_DEBUG') && WP_DEBUG ? '' : '.min';
        $this->plugin_name = $plugin_name;
        $this->version = $version;

        new DBUpdates();

        // Autoload system.
        spl_autoload_register(array($this, 'autoload'));

        EventfulMetaboxes::layout_metabox('eventful_layouts');
        EventfulMetaboxes::option_metabox('eventful_view_options');
        EventfulMetaboxes::shortcode_metabox('eventful_display_shortcode');
        EventfulSettings::settings('eventful_settings');

        $active_plugins = get_option('active_plugins');
        foreach ($active_plugins as $active_plugin) {
            $_temp = strpos($active_plugin, 'eventful-pro.php');
            if (false != $_temp) {
                add_filter('plugin_action_links_' . $active_plugin, array($this, 'add_plugin_action_links'));
            }
        }
    }

    public function add_plugin_action_links($links)
    {
        $new_links = array(
            sprintf('<a href="%s">%s</a>', admin_url('post-new.php?post_type=eventful'), esc_html__('Add New', 'eventful-pro')),
            sprintf('<a href="%s">%s</a>', admin_url('edit.php?post_type=eventful&page=eventful-pro-settings'), esc_html__('Settings', 'eventful-pro')),
        );
        return array_merge($new_links, $links);
    }

    /**
     * Autoload class files on demand
     *
     * @param string $class requested class name.
     * @since 2.2.0
     */
    private function autoload($class)
    {
        $name = explode('_', $class);
        if (isset($name[1])) {
            $class_name       = strtolower($name[1]);
            $eventful_pro_config_paths = array('views/', 'views/configs/settings/', 'views/configs/generator/');
            foreach ($eventful_pro_config_paths as $ta_eventful_pro_path) {
                $filename = plugin_dir_path(__FILE__) . '/' . $ta_eventful_pro_path . 'class-eventful-pro-' . $class_name . '.php';
                if (file_exists($filename)) {
                    require_once $filename;
                }
            }
        }
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Eventful_Pro_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Eventful_Pro_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        $current_screen        = get_current_screen();
        $the_current_post_type = $current_screen->post_type;
        if ('eventful' == $the_current_post_type) {
            wp_enqueue_style('eventful-pro-admin', EVENTFUL_PRO_URL . 'src/Admin/assets/css/eventful-pro-admin' . $this->suffix . '.css', array(), $this->version, 'all');
            wp_enqueue_style('icoFont', EVENTFUL_PRO_URL . 'src/assets/css/icofont' . $this->suffix . '.css', array(), $this->version, 'all');
        }
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Eventful_Pro_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Eventful_Pro_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        $current_screen        = get_current_screen();
        $the_current_post_type = $current_screen->post_type;
        if ('eventful' == $the_current_post_type) {
            wp_enqueue_script('eventful-pro-admin', EVENTFUL_PRO_URL . 'src/Admin/assets/js/eventful-pro-admin' . $this->suffix . '.js', array('jquery'), $this->version, false);
        }
    }

    /**
     * Add eventful admin columns.
     *
     * @since 2.0.0
     * @return statement
     */
    public function filter_eventful_pro_admin_column()
    {

        $admin_columns['cb']         = '<input type="checkbox" />';
        $admin_columns['title']      = esc_html__('Title', 'eventful-pro');
        $admin_columns['shortcode']  = esc_html__('Shortcode', 'eventful-pro');
        $admin_columns['eventful_pro_layout'] = esc_html__('Layout', 'eventful-pro');
        $admin_columns['date']       = esc_html__('Date', 'eventful-pro');

        return $admin_columns;
    }

    /**
     * Display admin columns for the eventfuls.
     *
     * @param mix    $column The columns.
     * @param string $post_id The post ID.
     * @return void
     */
    public function display_eventful_pro_admin_fields($column, $post_id)
    {


        $eventful_pro_layouts     = get_post_meta($post_id, 'eventful_layouts', true);
        $eventfuls_types = isset($eventful_pro_layouts['eventful_layout_preset']) ? $eventful_pro_layouts['eventful_layout_preset'] : '';
        switch ($column) {
            case 'shortcode':
                $column_field = '<input  class="ta_eventful_pro_input" style="width: 230px;padding: 4px 8px;cursor: pointer;" type="text" onClick="this.select();" readonly="readonly" value="[eventful id=&quot;' . $post_id . '&quot;]"/> <div class="eventful-pro-after-copy-text"><i class="icofont-check-circled"></i> ' . esc_html('Shortcode Copied to Clipboard!', 'eventful-pro') . ' </div>';
                echo $column_field;
                break;
            case 'eventful_pro_layout':
                $layout = ucwords(str_replace('_layout', ' ', $eventfuls_types));
                esc_html_e($layout, 'eventful-pro');
                break;
        } // end switch.
    }

    /**
     * If it is the plugins page.
     *
     * @since 2.2.0
     * @access private
     */
    private function is_plugins_screen()
    {
        return in_array(get_current_screen()->id, ['plugins', 'plugins-network']);
    }
}
