<?php

namespace ThemeAtelier\EventfulPro;

use ThemeAtelier\EventfulPro\Loader;
use ThemeAtelier\EventfulPro\Helpers\EventfulPostTypes;
use ThemeAtelier\EventfulPro\Admin\Admin;
use ThemeAtelier\EventfulPro\Frontend\Frontend;

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://https://https://themeatelier.net
 * @since      1.0.0
 *
 * @package    Eventful_Pro
 * @subpackage Eventful_Pro/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Eventful_Pro
 * @subpackage Eventful_Pro/includes
 * @author     ThemeAtelier <themeatelierbd@gmail.com>
 */
class EventfulPro
{
    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $plugin_name    The string used to uniquely identify this plugin.
     */
    protected $plugin_name = EVENTFUL_PRO_BASENAME;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $version    The current version of the plugin.
     */
    protected $version;

    /**
     * Plugin slug
     *
     * @since    1.0.0
     * @access   protected
     * @var string
     */
    protected $plugin_slug;

    /**
     * Main Loader.
     *
     * The loader that's responsible for maintaining and registering all hooks that empowers
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var object
     */
    protected $loader;

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct()
    {
        $this->version     = EVENTFUL_PRO_VERSION;
        $this->plugin_slug = 'eventful-pro';
        $this->load_dependencies();
        $this->define_constants();
        $this->define_admin_hooks();
        $this->define_public_hooks();
        $this->define_common_hooks();
        // $this->set_salocale();

        add_action('activated_plugin', array($this, 'redirect_to'));
    }

    /**
     * Define constant if not already set
     *
     * @since 2.2.0
     *
     * @param string      $name Define constant.
     * @param string|bool $value Define constant.
     */
    public function define($name, $value)
    {
        if (!defined($name)) {
            define($name, $value);
        }
    }

    /**
     * Define constants
     *
     * @since 2.2.0
     */
    public function define_constants()
    {
        $this->define('EVENTFUL_PRO_PLUGIN_NAME', $this->plugin_name);
        $this->define('EVENTFUL_PRO_PATH', plugin_dir_path(dirname(__FILE__)));
        $this->define('EVENTFUL_PRO_TEMPLATE_PATH', plugin_dir_path(dirname(__FILE__)) . 'public/templates/');
        $this->define('EVENTFUL_PRO_URL', plugin_dir_url(dirname(__FILE__)));
    }

    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - Eventful_Pro_Loader. Orchestrates the hooks of the plugin.
     * - Eventful_Pro_i18n. Defines internationalization functionality.
     * - Eventful_Pro_Admin. Defines all hooks for the admin area.
     * - Eventful_Pro_Public. Defines all hooks for the public side of the site.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function load_dependencies()
    {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        $this->loader = new Loader();
    }

    /**
     * Register common hooks.
     *
     * @since 1.0.0
     * @access private
     */
    private function define_common_hooks()
    {
        $common_hooks = new EventfulPostTypes(EVENTFUL_PRO_PLUGIN_NAME, EVENTFUL_PRO_VERSION);
        $this->loader->add_action('init', $common_hooks, 'register_eventful_pro_post_type', 10);
    }

    /**
     * Register all of the hooks related to the admin area functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_admin_hooks()
    {
        $plugin_admin = new Admin(EVENTFUL_PRO_PLUGIN_NAME, EVENTFUL_PRO_VERSION);

        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');

        $this->loader->add_filter('manage_eventful_posts_columns', $plugin_admin, 'filter_eventful_pro_admin_column');
        $this->loader->add_action('manage_eventful_posts_custom_column', $plugin_admin, 'display_eventful_pro_admin_fields', 10, 2);
    }

    /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_public_hooks()
    {

        $plugin_public = new Frontend(EVENTFUL_PRO_PLUGIN_NAME, EVENTFUL_PRO_VERSION);

        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run()
    {
        $this->loader->run();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function get_plugin_name()
    {
        return $this->plugin_name;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @since     1.0.0
     * @return    Eventful_Pro_Loader    Orchestrates the hooks of the plugin.
     */
    public function get_loader()
    {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public function get_version()
    {
        return $this->version;
    }

    public function redirect_to($plugin)
    {
        deactivate_plugins('eventful/eventful.php');

        if (EVENTFUL_PRO_BASENAME === $plugin) {
            $redirect_url = admin_url('edit.php?post_type=eventful&page=eventful-pro-settings');
            exit(wp_kses_post(wp_safe_redirect($redirect_url)));
        }
    }
}
